@@ -2,7 +2,7 @@ cNDWol<-function(alpha,n, method=NA, n.mc=10000){
   outp<-list()
   outp$stat.name<-"Nemenyi, Damico-Wolfe Y*"
   
-  if(alpha>1||alpha<0||class(alpha)!="numeric"){
+  if(alpha>1||alpha<0||!is.numeric(alpha)){
     cat('Error: Check alpha value! \n')
     return(alpha)
   }    
